# Managed API for Jira Service Management Cloud Assets
Managed API for Jira Service Management Cloud Assets is an API Client for Jira Service Management Cloud Assets by [Adaptavist](https://www.adaptavist.com/) primarily designed for the use in [ScriptRunner Connect](https://scriptrunnerconnect.com). You can read more about Managed APIs [here](https://docs.adaptavist.com/src/managed-apis).

This is a runtime agnostic version of the Managed API (with `core` suffix) that makes it easy to port it to any runtime you may want to use this Managed API on.

# Platform specific ports
- [ScriptRunner Connect](https://www.npmjs.com/package/@managed-api/jira-service-management-cloud-assets-sr-connect)

# Supported API calls
- [fetch](https://docs.adaptavist.com/src/managed-apis/managed-api-abstractions)
- Aql
    - [getObjects](https://developer.atlassian.com/cloud/assets/rest/api-group-aql/#api-aql-objects-get)
- Config
    - [createConfigStatus](https://developer.atlassian.com/cloud/assets/rest/api-group-config/#api-config-statustype-post)
    - [deleteConfigStatus](https://developer.atlassian.com/cloud/assets/rest/api-group-config/#api-config-statustype-id-delete)
    - [getConfigStatus](https://developer.atlassian.com/cloud/assets/rest/api-group-config/#api-config-statustype-id-get)
    - [getConfigStatuses](https://developer.atlassian.com/cloud/assets/rest/api-group-config/#api-config-statustype-get)
    - [updateConfigStatus](https://developer.atlassian.com/cloud/assets/rest/api-group-config/#api-config-statustype-id-put)
- Global
    - [updateGlobalObjectSchema](https://developer.atlassian.com/cloud/assets/rest/api-group-global/#api-global-config-objectschema-id-property-post)
- Icon
    - [getGlobalIcons](https://developer.atlassian.com/cloud/assets/rest/api-group-icon/#api-icon-global-get)
    - [getIcon](https://developer.atlassian.com/cloud/assets/rest/api-group-icon/#api-icon-id-get)
- Import
    - [startImport](https://developer.atlassian.com/cloud/assets/rest/api-group-import/#api-import-start-id-post)
- Object
    - [createObject](https://developer.atlassian.com/cloud/assets/rest/api-group-object/#api-object-create-post)
    - [deleteObject](https://developer.atlassian.com/cloud/assets/rest/api-group-object/#api-object-id-delete)
    - [getObject](https://developer.atlassian.com/cloud/assets/rest/api-group-object/#api-object-id-get)
    - [getObjectsByAql](https://developer.atlassian.com/cloud/assets/rest/api-group-object/#api-object-aql-post)
    - [getObjectsWithAql](https://developer.atlassian.com/cloud/assets/rest/api-group-object/#api-object-navlist-aql-post)
    - [updateObject](https://developer.atlassian.com/cloud/assets/rest/api-group-object/#api-object-id-put)
    - Attribute
        - [getAttributes](https://developer.atlassian.com/cloud/assets/rest/api-group-object/#api-object-id-attributes-get)
    - History
        - [getHistory](https://developer.atlassian.com/cloud/assets/rest/api-group-object/#api-object-id-history-get)
    - Reference
        - [getReferences](https://developer.atlassian.com/cloud/assets/rest/api-group-object/#api-object-id-referenceinfo-get)
    - Schema
        - [createSchema](https://developer.atlassian.com/cloud/assets/rest/api-group-objectschema/#api-objectschema-create-post)
        - [deleteSchema](https://developer.atlassian.com/cloud/assets/rest/api-group-objectschema/#api-objectschema-id-delete)
        - [getSchema](https://developer.atlassian.com/cloud/assets/rest/api-group-objectschema/#api-objectschema-id-get)
        - [getSchemaObjectTypeAttributes](https://developer.atlassian.com/cloud/assets/rest/api-group-objectschema/#api-objectschema-id-attributes-get)
        - [getSchemaObjectTypes](https://developer.atlassian.com/cloud/assets/rest/api-group-objectschema/#api-objectschema-id-objecttypes-flat-get)
        - [getSchemas](https://developer.atlassian.com/cloud/assets/rest/api-group-objectschema/#api-objectschema-list-get)
        - [updateSchema](https://developer.atlassian.com/cloud/assets/rest/api-group-objectschema/#api-objectschema-id-put)
    - Ticket
        - [getConnectedTickets](https://developer.atlassian.com/cloud/assets/rest/api-group-objectconnectedtickets/#api-objectconnectedtickets-objectid-tickets-get)
    - Type
        - [changeTypePosition](https://developer.atlassian.com/cloud/assets/rest/api-group-objecttype/#api-objecttype-id-position-post)
        - [createType](https://developer.atlassian.com/cloud/assets/rest/api-group-objecttype/#api-objecttype-create-post)
        - [deleteType](https://developer.atlassian.com/cloud/assets/rest/api-group-objecttype/#api-objecttype-id-delete)
        - [getType](https://developer.atlassian.com/cloud/assets/rest/api-group-objecttype/#api-objecttype-id-get)
        - [getTypeAttributes](https://developer.atlassian.com/cloud/assets/rest/api-group-objecttype/#api-objecttype-id-attributes-get)
        - [updateType](https://developer.atlassian.com/cloud/assets/rest/api-group-objecttype/#api-objecttype-id-put)
        - Attribute
            - [createAttribute](https://developer.atlassian.com/cloud/assets/rest/api-group-objecttypeattribute/#api-objecttypeattribute-objecttypeid-post)
            - [deleteAttribute](https://developer.atlassian.com/cloud/assets/rest/api-group-objecttypeattribute/#api-objecttypeattribute-id-delete)
            - [updateAttribute](https://developer.atlassian.com/cloud/assets/rest/api-group-objecttypeattribute/#api-objecttypeattribute-objecttypeid-id-put)
- Progress
    - [getImportProgress](https://developer.atlassian.com/cloud/assets/rest/api-group-progress/#api-progress-category-imports-id-get)


# Porting to other runtimes
While the primary reason for creating Managed APIs was to use them in [ScriptRunner Connect](https://scriptrunnerconnect.com) runtime, then you can easily port them to any runtime of your choosing.

You can do so by extending the `*Core` Managed API class where you'll be asked to provide implementation for `getPlatformImplementation` function. In this implementation you have to specify how to perform buffer encoding/decoding operations and how to perform HTTP calls:
```typescript
{
    buffer: {
        encode(input: string): ArrayBuffer;
        decode(input: ArrayBuffer): string;
    },
    performHttpCall(request: Request): Promise<Response>
}
```

Here is an example how to create a [Node](https://nodejs.org/en/) port of the Managed API:
```typescript
import { JiraServiceManagementCloudAssetsApiCore } from "@managed-api/jira-service-management-cloud-assets-core";
import { PlatformImplementation, Request, Response, Headers } from "@managed-api/commons-core";
import fetch from "node-fetch";

export class JiraServiceManagementCloudAssetsApi extends JiraServiceManagementCloudAssetsApiCore {
    constructor(private baseUrl: string, private authToken: string) {
        super();
    }

    protected getPlatformImplementation(): PlatformImplementation {
        return {
            buffer: {
                encode: (input) => Buffer.from(input, 'utf-8'),
                decode: (input) => Buffer.from(input).toString('utf-8')
            },
            performHttpCall: (request) => this.performHttpCall(request)
        };
    }
    
    private async performHttpCall(request: Request): Promise<Response> {
        const requestUrl = `${this.baseUrl}${request.url}`; // Substitute base URL
        request.headers.set('Authorization', `Basic ${this.authToken}`); // Substitute auth token
        const response = await fetch(requestUrl, {
            method: request.method,
            headers: request.headers as any,
            body: request.method.toLowerCase() !== 'get' ? Buffer.from((await request.arrayBuffer()) ?? new ArrayBuffer(0)) : undefined
        });

        const apiHeaders = new Headers();
        response.headers.forEach((value, key) => apiHeaders.append(key, value));

        const body = await response.arrayBuffer();

        return super.buildResponse(response.url, response.status, response.statusText, apiHeaders, body);
    }
}
```

Please note that the authentication handling details may not be accurate and serve as an example. If you wish to use these Managed APIs without having to concern yourself how to deal with and secure authentication details when working with APIs, then feel free to evaluate [ScriptRunner Connect](https://scriptrunnerconnect.com) platform.

# Contact
At this time Managed APIs are unlicensed and close sourced, but feel free to drop an email to [eknoll@adaptavist.com](mailto://eknoll@adaptavist.com) for ideas, suggestions and improvements.

 # Changelog
# 2.1.0

- Removed non-empty body from HEAD requests.

# 2.0.0

- # Breaking change: URL and query string parameters are now URL encoded, meaning if you encoded them explicitly before you have to remove your own encoding, otherwise they will get double encoded.

- # Updated OpenApi Specification.

- # Added support for the following Object method:

    * [Fetch Objects by AQL](https://developer.atlassian.com/cloud/assets/rest/api-group-object/#api-object-aql-post) that can be used as `Object.getObjectsByAql` or `All.getObjectsByAql`.

Copyright Adaptavist 2025 (c) All rights reserved