/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { ObjectTypeAttributesToDisplay } from "../definitions/ObjectTypeAttributesToDisplay";
export interface ObjectFilterParams {
    /**
     * The AQL that will fetch the objects. The object type parameter will be appended implicitly to this AQL
     */
    qlQuery: string;
    objectTypeId: string;
    /**
     * The requested page to be loaded for a paginated result. The default value is page = 1
     */
    page?: number;
    /**
     * How many objects should be returned in the request. It is used with page attribute for pagination.
     */
    resultsPerPage: number;
    /**
     * Which attribute should be used to order by. The preferred way is to use an order by in `qlQuery` and not pass this argument.
     */
    orderByTypeAttrId?: number;
    /**
     * Sort objects in ascending order or descending order based on the attribute identified by orderByTypeAttrId. 1 means ascending all other values mean descending. The preferred way is to not supply the asc parameter and use an order by in `qlQuery` instead.
     */
    asc?: number;
    /**
     * Identifies an object that should be included in the result. The page will be calculated accordingly to include the object specified in the result set
     */
    objectId?: string;
    objectSchemaId: string;
    /**
     * Should attribute values be included in the response.
     */
    includeAttributes?: boolean;
    /**
     * Identifies the attributes which values should be included in the response. Note that the includeAttributes must be specified to true in order for this parameter to be used.
     */
    attributesToDisplay?: ObjectTypeAttributesToDisplay;
}
//# sourceMappingURL=ObjectFilterParams.d.ts.map