/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { ObjectAsResponse } from "../definitions/ObjectAsResponse";
import { ObjectTypeAttributeAsResponse } from "../definitions/ObjectTypeAttributeAsResponse";
export interface ObjectListResultAsResponse {
    /**
     * The actual objects
     */
    objectEntries: Array<ObjectAsResponse>;
    /**
     * The object type attributes that are present in the object entries
     */
    objectTypeAttributes?: Array<ObjectTypeAttributeAsResponse>;
    /**
     * Deprecated field that shows which object type id the result is for. Not applicable when using AQL
     */
    objectTypeId?: string;
    /**
     * Deprecated field should not be used.
     */
    objectTypeIsInherited?: boolean;
    /**
     * Deprecated field should not be used.
     */
    abstractObjectType?: boolean;
    /**
     * The total amount of objects that was matched in the search query. This number may be greater than the amount of objects currently shown
     */
    totalFilterCount: number;
    /**
     * The offset of the first object in the search query that is present in the result, used for pagination
     */
    startIndex: number;
    /**
     * The index of the last object present in the result of the search query
     */
    toIndex: number;
    /**
     * The amount of objects currently returned per page in the result set
     */
    pageObjectSize: number;
    /**
     * The current page of objects in the result set pagination
     */
    pageNumber: number;
    /**
     * Deprecated field - The object type attribute id used for sorting
     */
    orderByTypeAttrId?: number;
    /**
     * Deprecated field - The sort order, used in conjunction with the orderByTypeAttrId
     */
    orderWay?: string;
    /**
     * Deprecated field - The field is used for basic search
     */
    filters?: any;
    /**
     * The AQL that was used to find the object result set
     */
    qlQuery: string;
    /**
     * Determines if the query was based on an AQL or by basic search
     */
    qlQuerySearchResult?: boolean;
    /**
     * Deprecated, use `qlQuery` instead
     */
    iql: string;
    /**
     * Deprecated, use `qlQuerySearchResult` instead
     */
    iqlSearchResult?: boolean;
    /**
     * Is it possible to transform this AQL to basic search or vice versa
     */
    conversionPossible?: boolean;
    /**
     * Deprecated field should not be used
     */
    matchedFilterValues?: any;
    /**
     * Deprecated field should not be used
     */
    inheritanceTree?: any;
}
//# sourceMappingURL=ObjectListResultAsResponse.d.ts.map