/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
export interface ObjectTypeAttributeUpdate {
    name?: string;
    label?: boolean;
    description?: string;
    /**
  * | Value | Description|
  | ----- | ----------- |
  | 0 | Default|
  | 1 | Object reference|
  | 2 | User|
  | 4 | Group |
  | 7 | Status |
  
  */
    type?: number;
    /**
  * | Id | Description (mandatory if type = Default) |
  | -- | ----------- |
  | -1 | None |
  | 0 | Text |
  | 1 | Integer |
  | 2 | Boolean |
  | 3 | Double |
  | 4 | Date |
  | 5 | Time |
  | 6 | DateTime |
  | 7 | Url |
  | 8 | Email |
  | 9 | Textarea |
  | 10 | Select |
  | 11 | IP Address |
  
  */
    defaultTypeId?: number;
    /**
     * It is mandatory for Type = Object reference and should point to the referenced object type id
     */
    typeValue?: string;
    /**
     * Valid for Type User. The Jira groups to restrict selection to
     */
    typeValueMulti?: Array<string>;
    /**
     * Valid for Type Url, User, Object and Confluence. For Url (DISABLED, ENABLED), for Object (ReferenceTypeId), for User (SHOW_PROFILE, HIDE_PROFILE), for Confluence (Confluence Space Id). It is mandatory for Type = Object reference
     */
    additionalValue?: string;
    /**
     * Valid for Type Email, Select, Object, User, Group, Version and Project
     */
    minimumCardinality?: number;
    /**
     * Valid for Type Email, Select, Object, User, Group, Version and Project
     */
    maximumCardinality?: number;
    /**
     * Valid for Integer and Double object type attributes
     */
    suffix?: string;
    /**
     * Valid for Type = Object reference and describes if children object types should be included in the selectable objects as well
     */
    includeChildObjectTypes?: boolean;
    /**
     * Hide the object type attributes for Assets Users
     */
    hidden?: boolean;
    /**
     * Should the values be unique for object attributes associated with this object type attribute
     */
    uniqueAttribute?: boolean;
    /**
     * Valid for Type Integer and Double. Should a sum be included in the view
     */
    summable?: boolean;
    /**
     * Valid for Type Text and Email
     */
    regexValidation?: string;
    /**
     * Valid for Type object reference. Allows specifying an AQL query to restrict which objects are selectable.
     */
    qlQuery?: string;
    /**
     * Deprecated. Use `qlQuery` instead. Valid for Type object reference.
     */
    iql?: string;
    /**
     * Valid for Type Select. A comma separated list of all chosable options
     */
    options?: string;
}
//# sourceMappingURL=ObjectTypeAttributeUpdate.d.ts.map