/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { GetObjectsRequest, GetObjectsResponseOK } from "./types/aql";
import { GetIconRequest, GetIconResponseOK } from "./types/icon";
import { GetGlobalIconsRequest, GetGlobalIconsResponseOK } from "./types/icon";
import { StartImportRequest, StartImportResponseOK } from "./types/import";
import { GetObjectAttributesRequest, GetObjectAttributesResponseOK } from "./types/object/attribute";
import { GetObjectHistoryRequest, GetObjectHistoryResponseOK } from "./types/object/history";
import { GetObjectReferencesRequest, GetObjectReferencesResponseOK } from "./types/object/reference";
import { GetObjectConnectedTicketsRequest, GetObjectConnectedTicketsResponseOK } from "./types/object/ticket";
import { GetObjectSchemasRequest, GetObjectSchemasResponseOK } from "./types/object/schema";
import { CreateObjectSchemaRequest, CreateObjectSchemaResponseOK } from "./types/object/schema";
import { GetObjectSchemaRequest, GetObjectSchemaResponseOK } from "./types/object/schema";
import { UpdateObjectSchemaRequest, UpdateObjectSchemaResponseOK } from "./types/object/schema";
import { DeleteObjectSchemaRequest, DeleteObjectSchemaResponseOK } from "./types/object/schema";
import { GetObjectSchemaObjectTypeAttributesRequest, GetObjectSchemaObjectTypeAttributesResponseOK } from "./types/object/schema";
import { GetObjectSchemaObjectTypesRequest, GetObjectSchemaObjectTypesResponseOK } from "./types/object/schema";
import { CreateObjectTypeAttributeRequest, CreateObjectTypeAttributeResponseOK } from "./types/object/type/attribute";
import { UpdateObjectTypeAttributeRequest, UpdateObjectTypeAttributeResponseOK } from "./types/object/type/attribute";
import { DeleteObjectTypeAttributeRequest, DeleteObjectTypeAttributeResponseOK } from "./types/object/type/attribute";
import { GetObjectTypeRequest, GetObjectTypeResponseOK } from "./types/object/type";
import { UpdateObjectTypeRequest, UpdateObjectTypeResponseOK } from "./types/object/type";
import { DeleteObjectTypeRequest, DeleteObjectTypeResponseOK } from "./types/object/type";
import { GetObjectTypeAttributesRequest, GetObjectTypeAttributesResponseOK } from "./types/object/type";
import { ChangeObjectTypePositionRequest, ChangeObjectTypePositionResponseOK } from "./types/object/type";
import { CreateObjectTypeRequest, CreateObjectTypeResponseOK } from "./types/object/type";
import { GetObjectRequest, GetObjectResponseOK } from "./types/object";
import { UpdateObjectRequest, UpdateObjectResponseOK } from "./types/object";
import { DeleteObjectRequest, DeleteObjectResponseOK } from "./types/object";
import { CreateObjectRequest, CreateObjectResponseOK } from "./types/object";
import { GetObjectsWithAqlRequest, GetObjectsWithAqlResponseOK } from "./types/object";
import { GetObjectsByAqlRequest, GetObjectsByAqlResponseOK } from "./types/object";
import { GetImportProgressRequest, GetImportProgressResponseOK } from "./types/progress";
import { GetConfigStatusesRequest, GetConfigStatusesResponseOK } from "./types/config";
import { CreateConfigStatusRequest, CreateConfigStatusResponseOK } from "./types/config";
import { GetConfigStatusRequest, GetConfigStatusResponseOK } from "./types/config";
import { UpdateConfigStatusRequest, UpdateConfigStatusResponseOK } from "./types/config";
import { DeleteConfigStatusRequest, DeleteConfigStatusResponseOK } from "./types/config";
import { UpdateGlobalObjectSchemaRequest, UpdateGlobalObjectSchemaResponseOK } from "./types/global";
import { BaseApiCore, Headers, Response, ErrorStrategyOptionType, PlatformImplementation } from "@managed-api/commons-core";
import { CommonError, AdditionalErrorTypes, ErrorStrategyHandlers, ErrorStrategyOption } from "./errorStrategy";
import { ErrorStrategyBuilder } from "./builders/errorStrategy";
export interface JiraServiceManagementCloudAssetsApiCoreOptions extends ErrorStrategyOption {
}
declare type GetGlobalErrorStrategy = () => ErrorStrategyOptionType<CommonError, AdditionalErrorTypes, ErrorStrategyHandlers, ErrorStrategyBuilder> | undefined;
export declare abstract class JiraServiceManagementCloudAssetsApiCore extends BaseApiCore {
    private options?;
    Aql: AqlGroup;
    Icon: IconGroup;
    Import: ImportGroup;
    Object: ObjectGroup;
    Progress: ProgressGroup;
    Config: ConfigGroup;
    Global: GlobalGroup;
    All: AllGroup;
    constructor(options?: JiraServiceManagementCloudAssetsApiCoreOptions | undefined);
    setGlobalErrorStrategy(errorStrategy: ErrorStrategyOptionType<CommonError, AdditionalErrorTypes, ErrorStrategyHandlers, ErrorStrategyBuilder>): void;
    protected buildResponse(url: string, status: number, statusText: string, headers: Headers, body?: string | ArrayBuffer): Response<any>;
    private getGlobalErrorStrategy;
}
declare class AllGroup {
    private Aql;
    private Icon;
    private Import;
    private Object;
    private Progress;
    private Config;
    private Global;
    constructor(Aql: AqlGroup, Icon: IconGroup, Import: ImportGroup, Object: ObjectGroup, Progress: ProgressGroup, Config: ConfigGroup, Global: GlobalGroup);
    /**
     * Deprecated from <b>1 May 2024</b>. Please use POST `/object/aql` instead. Find objects based on Assets Query Language (AQL)
     * Alternative usage: Aql.getObjects
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-aql/#api-aql-objects-get
     * @param options Request options.
     */
    getObjects<T = GetObjectsResponseOK>(options: GetObjectsRequest): Promise<GetObjectsResponseOK | T>;
    /**
     * Load a single icon by id
     * Alternative usage: Icon.getIcon
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-icon/#api-icon-id-get
     * @param options Request options.
     */
    getIcon<T = GetIconResponseOK>(options: GetIconRequest): Promise<GetIconResponseOK | T>;
    /**
     * Return all global icons i.e. icons not associated with a particular object schema
     * Alternative usage: Icon.getGlobalIcons
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-icon/#api-icon-global-get
     * @param options Request options.
     */
    getGlobalIcons<T = GetGlobalIconsResponseOK>(options: GetGlobalIconsRequest): Promise<GetGlobalIconsResponseOK | T>;
    /**
     * Start configured imports. To see an ongoing import see the Progress resource
     * Alternative usage: Import.startImport
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-import/#api-import-start-id-post
     * @param options Request options.
     */
    startImport<T = StartImportResponseOK>(options: StartImportRequest): Promise<StartImportResponseOK | T>;
    /**
     * Load one object
     * Alternative usage: Object.getObject
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-object/#api-object-id-get
     * @param options Request options.
     */
    getObject<T = GetObjectResponseOK>(options: GetObjectRequest): Promise<GetObjectResponseOK | T>;
    /**
     * Update an existing object in Assets
     * Alternative usage: Object.updateObject
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-object/#api-object-id-put
     * @param options Request options.
     */
    updateObject<T = UpdateObjectResponseOK>(options: UpdateObjectRequest): Promise<UpdateObjectResponseOK | T>;
    /**
     * Delete the referenced object
     * Alternative usage: Object.deleteObject
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-object/#api-object-id-delete
     * @param options Request options.
     */
    deleteObject<T = DeleteObjectResponseOK>(options: DeleteObjectRequest): Promise<DeleteObjectResponseOK | T>;
    /**
     * Create a new object in Assets
     * Alternative usage: Object.createObject
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-object/#api-object-create-post
     * @param options Request options.
     */
    createObject<T = CreateObjectResponseOK>(options: CreateObjectRequest): Promise<CreateObjectResponseOK | T>;
    /**
     * Retrieve a list of objects based on an AQL. Note that the preferred endpoint is /aql
     * Alternative usage: Object.getObjectsWithAql
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-object/#api-object-navlist-aql-post
     * @param options Request options.
     */
    getObjectsWithAql<T = GetObjectsWithAqlResponseOK>(options: GetObjectsWithAqlRequest): Promise<GetObjectsWithAqlResponseOK | T>;
    /**
     * Fetch Objects by AQL
     * Alternative usage: Object.getObjectsByAql
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-object/#api-object-aql-post
     * @param options Request options.
     */
    getObjectsByAql<T = GetObjectsByAqlResponseOK>(options: GetObjectsByAqlRequest): Promise<GetObjectsByAqlResponseOK | T>;
    /**
     * List all attributes for the given object
     * Alternative usage: Object.Attribute.getAttributes
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-object/#api-object-id-attributes-get
     * @param options Request options.
     */
    getObjectAttributes<T = GetObjectAttributesResponseOK>(options: GetObjectAttributesRequest): Promise<GetObjectAttributesResponseOK | T>;
    /**
     * Retrieve the history entries for this object
     * Alternative usage: Object.History.getHistory
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-object/#api-object-id-history-get
     * @param options Request options.
     */
    getObjectHistory<T = GetObjectHistoryResponseOK>(options: GetObjectHistoryRequest): Promise<GetObjectHistoryResponseOK | T>;
    /**
     * Find all references for an object
     * Alternative usage: Object.Reference.getReferences
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-object/#api-object-id-referenceinfo-get
     * @param options Request options.
     */
    getObjectReferences<T = GetObjectReferencesResponseOK>(options: GetObjectReferencesRequest): Promise<GetObjectReferencesResponseOK | T>;
    /**
     * Relation between Jira issues and Assets objects
     * Alternative usage: Object.Ticket.getConnectedTickets
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objectconnectedtickets/#api-objectconnectedtickets-objectid-tickets-get
     * @param options Request options.
     */
    getObjectConnectedTickets<T = GetObjectConnectedTicketsResponseOK>(options: GetObjectConnectedTicketsRequest): Promise<GetObjectConnectedTicketsResponseOK | T>;
    /**
     * Resource to find object schemas in Assets
     * Alternative usage: Object.Schema.getSchemas
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objectschema/#api-objectschema-list-get
     * @param options Request options.
     */
    getObjectSchemas<T = GetObjectSchemasResponseOK>(options: GetObjectSchemasRequest): Promise<GetObjectSchemasResponseOK | T>;
    /**
     * Create a new object schema
     * Alternative usage: Object.Schema.createSchema
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objectschema/#api-objectschema-create-post
     * @param options Request options.
     */
    createObjectSchema<T = CreateObjectSchemaResponseOK>(options: CreateObjectSchemaRequest): Promise<CreateObjectSchemaResponseOK | T>;
    /**
     * Find a schema by id
     * Alternative usage: Object.Schema.getSchema
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objectschema/#api-objectschema-id-get
     * @param options Request options.
     */
    getObjectSchema<T = GetObjectSchemaResponseOK>(options: GetObjectSchemaRequest): Promise<GetObjectSchemaResponseOK | T>;
    /**
     * Update an object schema
     * Alternative usage: Object.Schema.updateSchema
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objectschema/#api-objectschema-id-put
     * @param options Request options.
     */
    updateObjectSchema<T = UpdateObjectSchemaResponseOK>(options: UpdateObjectSchemaRequest): Promise<UpdateObjectSchemaResponseOK | T>;
    /**
     * Delete a schema
     * Alternative usage: Object.Schema.deleteSchema
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objectschema/#api-objectschema-id-delete
     * @param options Request options.
     */
    deleteObjectSchema<T = DeleteObjectSchemaResponseOK>(options: DeleteObjectSchemaRequest): Promise<DeleteObjectSchemaResponseOK | T>;
    /**
     * Find all object type attributes for this object schema
     * Alternative usage: Object.Schema.getSchemaObjectTypeAttributes
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objectschema/#api-objectschema-id-attributes-get
     * @param options Request options.
     */
    getObjectSchemaObjectTypeAttributes<T = GetObjectSchemaObjectTypeAttributesResponseOK>(options: GetObjectSchemaObjectTypeAttributesRequest): Promise<GetObjectSchemaObjectTypeAttributesResponseOK | T>;
    /**
     * Find all object types for this object schema
     * Alternative usage: Object.Schema.getSchemaObjectTypes
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objectschema/#api-objectschema-id-objecttypes-flat-get
     * @param options Request options.
     */
    getObjectSchemaObjectTypes<T = GetObjectSchemaObjectTypesResponseOK>(options: GetObjectSchemaObjectTypesRequest): Promise<GetObjectSchemaObjectTypesResponseOK | T>;
    /**
     * Find an object type by id
     * Alternative usage: Object.Type.getType
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objecttype/#api-objecttype-id-get
     * @param options Request options.
     */
    getObjectType<T = GetObjectTypeResponseOK>(options: GetObjectTypeRequest): Promise<GetObjectTypeResponseOK | T>;
    /**
     * Update an existing object type
     * Alternative usage: Object.Type.updateType
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objecttype/#api-objecttype-id-put
     * @param options Request options.
     */
    updateObjectType<T = UpdateObjectTypeResponseOK>(options: UpdateObjectTypeRequest): Promise<UpdateObjectTypeResponseOK | T>;
    /**
     * Delete an object type
     * Alternative usage: Object.Type.deleteType
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objecttype/#api-objecttype-id-delete
     * @param options Request options.
     */
    deleteObjectType<T = DeleteObjectTypeResponseOK>(options: DeleteObjectTypeRequest): Promise<DeleteObjectTypeResponseOK | T>;
    /**
     * Find all attributes for this object type
     * Alternative usage: Object.Type.getTypeAttributes
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objecttype/#api-objecttype-id-attributes-get
     * @param options Request options.
     */
    getObjectTypeAttributes<T = GetObjectTypeAttributesResponseOK>(options: GetObjectTypeAttributesRequest): Promise<GetObjectTypeAttributesResponseOK | T>;
    /**
     * Change position of this object type
     * Alternative usage: Object.Type.changeTypePosition
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objecttype/#api-objecttype-id-position-post
     * @param options Request options.
     */
    changeObjectTypePosition<T = ChangeObjectTypePositionResponseOK>(options: ChangeObjectTypePositionRequest): Promise<ChangeObjectTypePositionResponseOK | T>;
    /**
     * Create a new object type
     * Alternative usage: Object.Type.createType
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objecttype/#api-objecttype-create-post
     * @param options Request options.
     */
    createObjectType<T = CreateObjectTypeResponseOK>(options: CreateObjectTypeRequest): Promise<CreateObjectTypeResponseOK | T>;
    /**
     * Create a new attribute on the given object type
     * Alternative usage: Object.Type.Attribute.createAttribute
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objecttypeattribute/#api-objecttypeattribute-objecttypeid-post
     * @param options Request options.
     */
    createObjectTypeAttribute<T = CreateObjectTypeAttributeResponseOK>(options: CreateObjectTypeAttributeRequest): Promise<CreateObjectTypeAttributeResponseOK | T>;
    /**
     * Update an existing object type attribute
     * Alternative usage: Object.Type.Attribute.updateAttribute
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objecttypeattribute/#api-objecttypeattribute-objecttypeid-id-put
     * @param options Request options.
     */
    updateObjectTypeAttribute<T = UpdateObjectTypeAttributeResponseOK>(options: UpdateObjectTypeAttributeRequest): Promise<UpdateObjectTypeAttributeResponseOK | T>;
    /**
     * Delete an existing object type attribute
     * Alternative usage: Object.Type.Attribute.deleteAttribute
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objecttypeattribute/#api-objecttypeattribute-id-delete
     * @param options Request options.
     */
    deleteObjectTypeAttribute<T = DeleteObjectTypeAttributeResponseOK>(options: DeleteObjectTypeAttributeRequest): Promise<DeleteObjectTypeAttributeResponseOK | T>;
    /**
     * Show ongoing import process
     * Alternative usage: Progress.getImportProgress
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-progress/#api-progress-category-imports-id-get
     * @param options Request options.
     */
    getImportProgress<T = GetImportProgressResponseOK>(options: GetImportProgressRequest): Promise<GetImportProgressResponseOK | T>;
    /**
     * Find all status
     * Alternative usage: Config.getConfigStatuses
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-config/#api-config-statustype-get
     * @param options Request options.
     */
    getConfigStatuses<T = GetConfigStatusesResponseOK>(options: GetConfigStatusesRequest): Promise<GetConfigStatusesResponseOK | T>;
    /**
     * Create a new status
     * Alternative usage: Config.createConfigStatus
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-config/#api-config-statustype-post
     * @param options Request options.
     */
    createConfigStatus<T = CreateConfigStatusResponseOK>(options: CreateConfigStatusRequest): Promise<CreateConfigStatusResponseOK | T>;
    /**
     * Find a status by id
     * Alternative usage: Config.getConfigStatus
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-config/#api-config-statustype-id-get
     * @param options Request options.
     */
    getConfigStatus<T = GetConfigStatusResponseOK>(options: GetConfigStatusRequest): Promise<GetConfigStatusResponseOK | T>;
    /**
     * Update an existing status
     * Alternative usage: Config.updateConfigStatus
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-config/#api-config-statustype-id-put
     * @param options Request options.
     */
    updateConfigStatus<T = UpdateConfigStatusResponseOK>(options: UpdateConfigStatusRequest): Promise<UpdateConfigStatusResponseOK | T>;
    /**
     * Delete an existing status
     * Alternative usage: Config.deleteConfigStatus
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-config/#api-config-statustype-id-delete
     * @param options Request options.
     */
    deleteConfigStatus<T = DeleteConfigStatusResponseOK>(options: DeleteConfigStatusRequest): Promise<DeleteConfigStatusResponseOK | T>;
    /**
     * Update general configuration for object schema
     * Alternative usage: Global.updateGlobalObjectSchema
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-global/#api-global-config-objectschema-id-property-post
     * @param options Request options.
     */
    updateGlobalObjectSchema<T = UpdateGlobalObjectSchemaResponseOK>(options: UpdateGlobalObjectSchemaRequest): Promise<UpdateGlobalObjectSchemaResponseOK | T>;
}
declare class AqlGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Deprecated from <b>1 May 2024</b>. Please use POST `/object/aql` instead. Find objects based on Assets Query Language (AQL)
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-aql/#api-aql-objects-get
     * @param options Request options.
     */
    getObjects<T = GetObjectsResponseOK>(options: GetObjectsRequest): Promise<GetObjectsResponseOK | T>;
}
declare class IconGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Load a single icon by id
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-icon/#api-icon-id-get
     * @param options Request options.
     */
    getIcon<T = GetIconResponseOK>(options: GetIconRequest): Promise<GetIconResponseOK | T>;
    /**
     * Return all global icons i.e. icons not associated with a particular object schema
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-icon/#api-icon-global-get
     * @param options Request options.
     */
    getGlobalIcons<T = GetGlobalIconsResponseOK>(options: GetGlobalIconsRequest): Promise<GetGlobalIconsResponseOK | T>;
}
declare class ImportGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Start configured imports. To see an ongoing import see the Progress resource
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-import/#api-import-start-id-post
     * @param options Request options.
     */
    startImport<T = StartImportResponseOK>(options: StartImportRequest): Promise<StartImportResponseOK | T>;
}
declare class ObjectGroup {
    private implementation;
    private getGlobalErrorStrategy;
    Attribute: ObjectAttributeGroup;
    History: ObjectHistoryGroup;
    Reference: ObjectReferenceGroup;
    Ticket: ObjectTicketGroup;
    Schema: ObjectSchemaGroup;
    Type: ObjectTypeGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Load one object
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-object/#api-object-id-get
     * @param options Request options.
     */
    getObject<T = GetObjectResponseOK>(options: GetObjectRequest): Promise<GetObjectResponseOK | T>;
    /**
     * Update an existing object in Assets
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-object/#api-object-id-put
     * @param options Request options.
     */
    updateObject<T = UpdateObjectResponseOK>(options: UpdateObjectRequest): Promise<UpdateObjectResponseOK | T>;
    /**
     * Delete the referenced object
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-object/#api-object-id-delete
     * @param options Request options.
     */
    deleteObject<T = DeleteObjectResponseOK>(options: DeleteObjectRequest): Promise<DeleteObjectResponseOK | T>;
    /**
     * Create a new object in Assets
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-object/#api-object-create-post
     * @param options Request options.
     */
    createObject<T = CreateObjectResponseOK>(options: CreateObjectRequest): Promise<CreateObjectResponseOK | T>;
    /**
     * Retrieve a list of objects based on an AQL. Note that the preferred endpoint is /aql
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-object/#api-object-navlist-aql-post
     * @param options Request options.
     */
    getObjectsWithAql<T = GetObjectsWithAqlResponseOK>(options: GetObjectsWithAqlRequest): Promise<GetObjectsWithAqlResponseOK | T>;
    /**
     * Fetch Objects by AQL
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-object/#api-object-aql-post
     * @param options Request options.
     */
    getObjectsByAql<T = GetObjectsByAqlResponseOK>(options: GetObjectsByAqlRequest): Promise<GetObjectsByAqlResponseOK | T>;
}
declare class ObjectAttributeGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * List all attributes for the given object
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-object/#api-object-id-attributes-get
     * @param options Request options.
     */
    getAttributes<T = GetObjectAttributesResponseOK>(options: GetObjectAttributesRequest): Promise<GetObjectAttributesResponseOK | T>;
}
declare class ObjectHistoryGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Retrieve the history entries for this object
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-object/#api-object-id-history-get
     * @param options Request options.
     */
    getHistory<T = GetObjectHistoryResponseOK>(options: GetObjectHistoryRequest): Promise<GetObjectHistoryResponseOK | T>;
}
declare class ObjectReferenceGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Find all references for an object
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-object/#api-object-id-referenceinfo-get
     * @param options Request options.
     */
    getReferences<T = GetObjectReferencesResponseOK>(options: GetObjectReferencesRequest): Promise<GetObjectReferencesResponseOK | T>;
}
declare class ObjectTicketGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Relation between Jira issues and Assets objects
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objectconnectedtickets/#api-objectconnectedtickets-objectid-tickets-get
     * @param options Request options.
     */
    getConnectedTickets<T = GetObjectConnectedTicketsResponseOK>(options: GetObjectConnectedTicketsRequest): Promise<GetObjectConnectedTicketsResponseOK | T>;
}
declare class ObjectSchemaGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Resource to find object schemas in Assets
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objectschema/#api-objectschema-list-get
     * @param options Request options.
     */
    getSchemas<T = GetObjectSchemasResponseOK>(options: GetObjectSchemasRequest): Promise<GetObjectSchemasResponseOK | T>;
    /**
     * Create a new object schema
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objectschema/#api-objectschema-create-post
     * @param options Request options.
     */
    createSchema<T = CreateObjectSchemaResponseOK>(options: CreateObjectSchemaRequest): Promise<CreateObjectSchemaResponseOK | T>;
    /**
     * Find a schema by id
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objectschema/#api-objectschema-id-get
     * @param options Request options.
     */
    getSchema<T = GetObjectSchemaResponseOK>(options: GetObjectSchemaRequest): Promise<GetObjectSchemaResponseOK | T>;
    /**
     * Update an object schema
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objectschema/#api-objectschema-id-put
     * @param options Request options.
     */
    updateSchema<T = UpdateObjectSchemaResponseOK>(options: UpdateObjectSchemaRequest): Promise<UpdateObjectSchemaResponseOK | T>;
    /**
     * Delete a schema
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objectschema/#api-objectschema-id-delete
     * @param options Request options.
     */
    deleteSchema<T = DeleteObjectSchemaResponseOK>(options: DeleteObjectSchemaRequest): Promise<DeleteObjectSchemaResponseOK | T>;
    /**
     * Find all object type attributes for this object schema
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objectschema/#api-objectschema-id-attributes-get
     * @param options Request options.
     */
    getSchemaObjectTypeAttributes<T = GetObjectSchemaObjectTypeAttributesResponseOK>(options: GetObjectSchemaObjectTypeAttributesRequest): Promise<GetObjectSchemaObjectTypeAttributesResponseOK | T>;
    /**
     * Find all object types for this object schema
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objectschema/#api-objectschema-id-objecttypes-flat-get
     * @param options Request options.
     */
    getSchemaObjectTypes<T = GetObjectSchemaObjectTypesResponseOK>(options: GetObjectSchemaObjectTypesRequest): Promise<GetObjectSchemaObjectTypesResponseOK | T>;
}
declare class ObjectTypeGroup {
    private implementation;
    private getGlobalErrorStrategy;
    Attribute: ObjectTypeAttributeGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Find an object type by id
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objecttype/#api-objecttype-id-get
     * @param options Request options.
     */
    getType<T = GetObjectTypeResponseOK>(options: GetObjectTypeRequest): Promise<GetObjectTypeResponseOK | T>;
    /**
     * Update an existing object type
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objecttype/#api-objecttype-id-put
     * @param options Request options.
     */
    updateType<T = UpdateObjectTypeResponseOK>(options: UpdateObjectTypeRequest): Promise<UpdateObjectTypeResponseOK | T>;
    /**
     * Delete an object type
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objecttype/#api-objecttype-id-delete
     * @param options Request options.
     */
    deleteType<T = DeleteObjectTypeResponseOK>(options: DeleteObjectTypeRequest): Promise<DeleteObjectTypeResponseOK | T>;
    /**
     * Find all attributes for this object type
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objecttype/#api-objecttype-id-attributes-get
     * @param options Request options.
     */
    getTypeAttributes<T = GetObjectTypeAttributesResponseOK>(options: GetObjectTypeAttributesRequest): Promise<GetObjectTypeAttributesResponseOK | T>;
    /**
     * Change position of this object type
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objecttype/#api-objecttype-id-position-post
     * @param options Request options.
     */
    changeTypePosition<T = ChangeObjectTypePositionResponseOK>(options: ChangeObjectTypePositionRequest): Promise<ChangeObjectTypePositionResponseOK | T>;
    /**
     * Create a new object type
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objecttype/#api-objecttype-create-post
     * @param options Request options.
     */
    createType<T = CreateObjectTypeResponseOK>(options: CreateObjectTypeRequest): Promise<CreateObjectTypeResponseOK | T>;
}
declare class ObjectTypeAttributeGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Create a new attribute on the given object type
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objecttypeattribute/#api-objecttypeattribute-objecttypeid-post
     * @param options Request options.
     */
    createAttribute<T = CreateObjectTypeAttributeResponseOK>(options: CreateObjectTypeAttributeRequest): Promise<CreateObjectTypeAttributeResponseOK | T>;
    /**
     * Update an existing object type attribute
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objecttypeattribute/#api-objecttypeattribute-objecttypeid-id-put
     * @param options Request options.
     */
    updateAttribute<T = UpdateObjectTypeAttributeResponseOK>(options: UpdateObjectTypeAttributeRequest): Promise<UpdateObjectTypeAttributeResponseOK | T>;
    /**
     * Delete an existing object type attribute
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objecttypeattribute/#api-objecttypeattribute-id-delete
     * @param options Request options.
     */
    deleteAttribute<T = DeleteObjectTypeAttributeResponseOK>(options: DeleteObjectTypeAttributeRequest): Promise<DeleteObjectTypeAttributeResponseOK | T>;
}
declare class ProgressGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Show ongoing import process
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-progress/#api-progress-category-imports-id-get
     * @param options Request options.
     */
    getImportProgress<T = GetImportProgressResponseOK>(options: GetImportProgressRequest): Promise<GetImportProgressResponseOK | T>;
}
declare class ConfigGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Find all status
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-config/#api-config-statustype-get
     * @param options Request options.
     */
    getConfigStatuses<T = GetConfigStatusesResponseOK>(options: GetConfigStatusesRequest): Promise<GetConfigStatusesResponseOK | T>;
    /**
     * Create a new status
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-config/#api-config-statustype-post
     * @param options Request options.
     */
    createConfigStatus<T = CreateConfigStatusResponseOK>(options: CreateConfigStatusRequest): Promise<CreateConfigStatusResponseOK | T>;
    /**
     * Find a status by id
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-config/#api-config-statustype-id-get
     * @param options Request options.
     */
    getConfigStatus<T = GetConfigStatusResponseOK>(options: GetConfigStatusRequest): Promise<GetConfigStatusResponseOK | T>;
    /**
     * Update an existing status
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-config/#api-config-statustype-id-put
     * @param options Request options.
     */
    updateConfigStatus<T = UpdateConfigStatusResponseOK>(options: UpdateConfigStatusRequest): Promise<UpdateConfigStatusResponseOK | T>;
    /**
     * Delete an existing status
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-config/#api-config-statustype-id-delete
     * @param options Request options.
     */
    deleteConfigStatus<T = DeleteConfigStatusResponseOK>(options: DeleteConfigStatusRequest): Promise<DeleteConfigStatusResponseOK | T>;
}
declare class GlobalGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Update general configuration for object schema
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-global/#api-global-config-objectschema-id-property-post
     * @param options Request options.
     */
    updateGlobalObjectSchema<T = UpdateGlobalObjectSchemaResponseOK>(options: UpdateGlobalObjectSchemaRequest): Promise<UpdateGlobalObjectSchemaResponseOK | T>;
}
export {};
//# sourceMappingURL=index.d.ts.map