/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { BaseApiCore, constructUrl, executeHttpCall, Request, Response } from "@managed-api/commons-core";
import { constructHeaders, errorMessageBuilder } from "./common";
import { customErrorHandlers, errorStrategyBuilderConstructor } from "./errorStrategy";
export class JiraServiceManagementCloudAssetsApiCore extends BaseApiCore {
    constructor(options) {
        var _a, _b;
        super();
        this.options = options;
        if (!((_a = this.options) === null || _a === void 0 ? void 0 : _a.errorStrategy) && ((_b = this.options) === null || _b === void 0 ? void 0 : _b.errorStrategy) !== null) {
            this.setGlobalErrorStrategy((builder) => builder.retryOnRateLimiting(-1));
        }
        this.Aql = new AqlGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Icon = new IconGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Import = new ImportGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Object = new ObjectGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Progress = new ProgressGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Config = new ConfigGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Global = new GlobalGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.All = new AllGroup(this.Aql, this.Icon, this.Import, this.Object, this.Progress, this.Config, this.Global);
    }
    setGlobalErrorStrategy(errorStrategy) {
        var _a;
        this.options = {
            ...(_a = this.options, (_a !== null && _a !== void 0 ? _a : {})),
            errorStrategy,
        };
    }
    buildResponse(url, status, statusText, headers, body) {
        const response = new Response(url, status, statusText, headers, body);
        response.setBufferImplementation(this.implementation);
        return response;
    }
    getGlobalErrorStrategy() {
        var _a;
        return (_a = this.options) === null || _a === void 0 ? void 0 : _a.errorStrategy;
    }
}
class AllGroup {
    constructor(Aql, Icon, Import, Object, Progress, Config, Global) {
        this.Aql = Aql;
        this.Icon = Icon;
        this.Import = Import;
        this.Object = Object;
        this.Progress = Progress;
        this.Config = Config;
        this.Global = Global;
    }
    /**
     * Deprecated from <b>1 May 2024</b>. Please use POST `/object/aql` instead. Find objects based on Assets Query Language (AQL)
     * Alternative usage: Aql.getObjects
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-aql/#api-aql-objects-get
     * @param options Request options.
     */
    async getObjects(options) {
        return this.Aql.getObjects(options);
    }
    /**
     * Load a single icon by id
     * Alternative usage: Icon.getIcon
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-icon/#api-icon-id-get
     * @param options Request options.
     */
    async getIcon(options) {
        return this.Icon.getIcon(options);
    }
    /**
     * Return all global icons i.e. icons not associated with a particular object schema
     * Alternative usage: Icon.getGlobalIcons
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-icon/#api-icon-global-get
     * @param options Request options.
     */
    async getGlobalIcons(options) {
        return this.Icon.getGlobalIcons(options);
    }
    /**
     * Start configured imports. To see an ongoing import see the Progress resource
     * Alternative usage: Import.startImport
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-import/#api-import-start-id-post
     * @param options Request options.
     */
    async startImport(options) {
        return this.Import.startImport(options);
    }
    /**
     * Load one object
     * Alternative usage: Object.getObject
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-object/#api-object-id-get
     * @param options Request options.
     */
    async getObject(options) {
        return this.Object.getObject(options);
    }
    /**
     * Update an existing object in Assets
     * Alternative usage: Object.updateObject
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-object/#api-object-id-put
     * @param options Request options.
     */
    async updateObject(options) {
        return this.Object.updateObject(options);
    }
    /**
     * Delete the referenced object
     * Alternative usage: Object.deleteObject
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-object/#api-object-id-delete
     * @param options Request options.
     */
    async deleteObject(options) {
        return this.Object.deleteObject(options);
    }
    /**
     * Create a new object in Assets
     * Alternative usage: Object.createObject
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-object/#api-object-create-post
     * @param options Request options.
     */
    async createObject(options) {
        return this.Object.createObject(options);
    }
    /**
     * Retrieve a list of objects based on an AQL. Note that the preferred endpoint is /aql
     * Alternative usage: Object.getObjectsWithAql
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-object/#api-object-navlist-aql-post
     * @param options Request options.
     */
    async getObjectsWithAql(options) {
        return this.Object.getObjectsWithAql(options);
    }
    /**
     * Fetch Objects by AQL
     * Alternative usage: Object.getObjectsByAql
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-object/#api-object-aql-post
     * @param options Request options.
     */
    async getObjectsByAql(options) {
        return this.Object.getObjectsByAql(options);
    }
    /**
     * List all attributes for the given object
     * Alternative usage: Object.Attribute.getAttributes
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-object/#api-object-id-attributes-get
     * @param options Request options.
     */
    async getObjectAttributes(options) {
        return this.Object.Attribute.getAttributes(options);
    }
    /**
     * Retrieve the history entries for this object
     * Alternative usage: Object.History.getHistory
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-object/#api-object-id-history-get
     * @param options Request options.
     */
    async getObjectHistory(options) {
        return this.Object.History.getHistory(options);
    }
    /**
     * Find all references for an object
     * Alternative usage: Object.Reference.getReferences
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-object/#api-object-id-referenceinfo-get
     * @param options Request options.
     */
    async getObjectReferences(options) {
        return this.Object.Reference.getReferences(options);
    }
    /**
     * Relation between Jira issues and Assets objects
     * Alternative usage: Object.Ticket.getConnectedTickets
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objectconnectedtickets/#api-objectconnectedtickets-objectid-tickets-get
     * @param options Request options.
     */
    async getObjectConnectedTickets(options) {
        return this.Object.Ticket.getConnectedTickets(options);
    }
    /**
     * Resource to find object schemas in Assets
     * Alternative usage: Object.Schema.getSchemas
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objectschema/#api-objectschema-list-get
     * @param options Request options.
     */
    async getObjectSchemas(options) {
        return this.Object.Schema.getSchemas(options);
    }
    /**
     * Create a new object schema
     * Alternative usage: Object.Schema.createSchema
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objectschema/#api-objectschema-create-post
     * @param options Request options.
     */
    async createObjectSchema(options) {
        return this.Object.Schema.createSchema(options);
    }
    /**
     * Find a schema by id
     * Alternative usage: Object.Schema.getSchema
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objectschema/#api-objectschema-id-get
     * @param options Request options.
     */
    async getObjectSchema(options) {
        return this.Object.Schema.getSchema(options);
    }
    /**
     * Update an object schema
     * Alternative usage: Object.Schema.updateSchema
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objectschema/#api-objectschema-id-put
     * @param options Request options.
     */
    async updateObjectSchema(options) {
        return this.Object.Schema.updateSchema(options);
    }
    /**
     * Delete a schema
     * Alternative usage: Object.Schema.deleteSchema
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objectschema/#api-objectschema-id-delete
     * @param options Request options.
     */
    async deleteObjectSchema(options) {
        return this.Object.Schema.deleteSchema(options);
    }
    /**
     * Find all object type attributes for this object schema
     * Alternative usage: Object.Schema.getSchemaObjectTypeAttributes
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objectschema/#api-objectschema-id-attributes-get
     * @param options Request options.
     */
    async getObjectSchemaObjectTypeAttributes(options) {
        return this.Object.Schema.getSchemaObjectTypeAttributes(options);
    }
    /**
     * Find all object types for this object schema
     * Alternative usage: Object.Schema.getSchemaObjectTypes
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objectschema/#api-objectschema-id-objecttypes-flat-get
     * @param options Request options.
     */
    async getObjectSchemaObjectTypes(options) {
        return this.Object.Schema.getSchemaObjectTypes(options);
    }
    /**
     * Find an object type by id
     * Alternative usage: Object.Type.getType
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objecttype/#api-objecttype-id-get
     * @param options Request options.
     */
    async getObjectType(options) {
        return this.Object.Type.getType(options);
    }
    /**
     * Update an existing object type
     * Alternative usage: Object.Type.updateType
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objecttype/#api-objecttype-id-put
     * @param options Request options.
     */
    async updateObjectType(options) {
        return this.Object.Type.updateType(options);
    }
    /**
     * Delete an object type
     * Alternative usage: Object.Type.deleteType
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objecttype/#api-objecttype-id-delete
     * @param options Request options.
     */
    async deleteObjectType(options) {
        return this.Object.Type.deleteType(options);
    }
    /**
     * Find all attributes for this object type
     * Alternative usage: Object.Type.getTypeAttributes
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objecttype/#api-objecttype-id-attributes-get
     * @param options Request options.
     */
    async getObjectTypeAttributes(options) {
        return this.Object.Type.getTypeAttributes(options);
    }
    /**
     * Change position of this object type
     * Alternative usage: Object.Type.changeTypePosition
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objecttype/#api-objecttype-id-position-post
     * @param options Request options.
     */
    async changeObjectTypePosition(options) {
        return this.Object.Type.changeTypePosition(options);
    }
    /**
     * Create a new object type
     * Alternative usage: Object.Type.createType
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objecttype/#api-objecttype-create-post
     * @param options Request options.
     */
    async createObjectType(options) {
        return this.Object.Type.createType(options);
    }
    /**
     * Create a new attribute on the given object type
     * Alternative usage: Object.Type.Attribute.createAttribute
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objecttypeattribute/#api-objecttypeattribute-objecttypeid-post
     * @param options Request options.
     */
    async createObjectTypeAttribute(options) {
        return this.Object.Type.Attribute.createAttribute(options);
    }
    /**
     * Update an existing object type attribute
     * Alternative usage: Object.Type.Attribute.updateAttribute
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objecttypeattribute/#api-objecttypeattribute-objecttypeid-id-put
     * @param options Request options.
     */
    async updateObjectTypeAttribute(options) {
        return this.Object.Type.Attribute.updateAttribute(options);
    }
    /**
     * Delete an existing object type attribute
     * Alternative usage: Object.Type.Attribute.deleteAttribute
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objecttypeattribute/#api-objecttypeattribute-id-delete
     * @param options Request options.
     */
    async deleteObjectTypeAttribute(options) {
        return this.Object.Type.Attribute.deleteAttribute(options);
    }
    /**
     * Show ongoing import process
     * Alternative usage: Progress.getImportProgress
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-progress/#api-progress-category-imports-id-get
     * @param options Request options.
     */
    async getImportProgress(options) {
        return this.Progress.getImportProgress(options);
    }
    /**
     * Find all status
     * Alternative usage: Config.getConfigStatuses
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-config/#api-config-statustype-get
     * @param options Request options.
     */
    async getConfigStatuses(options) {
        return this.Config.getConfigStatuses(options);
    }
    /**
     * Create a new status
     * Alternative usage: Config.createConfigStatus
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-config/#api-config-statustype-post
     * @param options Request options.
     */
    async createConfigStatus(options) {
        return this.Config.createConfigStatus(options);
    }
    /**
     * Find a status by id
     * Alternative usage: Config.getConfigStatus
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-config/#api-config-statustype-id-get
     * @param options Request options.
     */
    async getConfigStatus(options) {
        return this.Config.getConfigStatus(options);
    }
    /**
     * Update an existing status
     * Alternative usage: Config.updateConfigStatus
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-config/#api-config-statustype-id-put
     * @param options Request options.
     */
    async updateConfigStatus(options) {
        return this.Config.updateConfigStatus(options);
    }
    /**
     * Delete an existing status
     * Alternative usage: Config.deleteConfigStatus
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-config/#api-config-statustype-id-delete
     * @param options Request options.
     */
    async deleteConfigStatus(options) {
        return this.Config.deleteConfigStatus(options);
    }
    /**
     * Update general configuration for object schema
     * Alternative usage: Global.updateGlobalObjectSchema
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-global/#api-global-config-objectschema-id-property-post
     * @param options Request options.
     */
    async updateGlobalObjectSchema(options) {
        return this.Global.updateGlobalObjectSchema(options);
    }
}
class AqlGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Deprecated from <b>1 May 2024</b>. Please use POST `/object/aql` instead. Find objects based on Assets Query Language (AQL)
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-aql/#api-aql-objects-get
     * @param options Request options.
     */
    async getObjects(options) {
        const { headers, errorStrategy, workspaceId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/jsm/assets/workspace/${encodeURIComponent(workspaceId)}/v1/aql/objects`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class IconGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Load a single icon by id
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-icon/#api-icon-id-get
     * @param options Request options.
     */
    async getIcon(options) {
        const { headers, errorStrategy, id, workspaceId } = options;
        const request = new Request("GET", `/jsm/assets/workspace/${encodeURIComponent(workspaceId)}/v1/icon/${encodeURIComponent(id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Return all global icons i.e. icons not associated with a particular object schema
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-icon/#api-icon-global-get
     * @param options Request options.
     */
    async getGlobalIcons(options) {
        const { headers, errorStrategy, workspaceId } = options;
        const request = new Request("GET", `/jsm/assets/workspace/${encodeURIComponent(workspaceId)}/v1/icon/global`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ImportGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Start configured imports. To see an ongoing import see the Progress resource
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-import/#api-import-start-id-post
     * @param options Request options.
     */
    async startImport(options) {
        const { headers, errorStrategy, id, workspaceId } = options;
        const request = new Request("POST", `/jsm/assets/workspace/${encodeURIComponent(workspaceId)}/v1/import/start/${encodeURIComponent(id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ObjectGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Attribute = new ObjectAttributeGroup(implementation, this.getGlobalErrorStrategy);
        this.History = new ObjectHistoryGroup(implementation, this.getGlobalErrorStrategy);
        this.Reference = new ObjectReferenceGroup(implementation, this.getGlobalErrorStrategy);
        this.Ticket = new ObjectTicketGroup(implementation, this.getGlobalErrorStrategy);
        this.Schema = new ObjectSchemaGroup(implementation, this.getGlobalErrorStrategy);
        this.Type = new ObjectTypeGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
     * Load one object
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-object/#api-object-id-get
     * @param options Request options.
     */
    async getObject(options) {
        const { headers, errorStrategy, id, workspaceId } = options;
        const request = new Request("GET", `/jsm/assets/workspace/${encodeURIComponent(workspaceId)}/v1/object/${encodeURIComponent(id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Update an existing object in Assets
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-object/#api-object-id-put
     * @param options Request options.
     */
    async updateObject(options) {
        const { body, headers, errorStrategy, id, workspaceId } = options;
        const request = new Request("PUT", `/jsm/assets/workspace/${encodeURIComponent(workspaceId)}/v1/object/${encodeURIComponent(id)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Delete the referenced object
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-object/#api-object-id-delete
     * @param options Request options.
     */
    async deleteObject(options) {
        const { headers, errorStrategy, id, workspaceId } = options;
        const request = new Request("DELETE", `/jsm/assets/workspace/${encodeURIComponent(workspaceId)}/v1/object/${encodeURIComponent(id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Create a new object in Assets
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-object/#api-object-create-post
     * @param options Request options.
     */
    async createObject(options) {
        const { body, headers, errorStrategy, workspaceId } = options;
        const request = new Request("POST", `/jsm/assets/workspace/${encodeURIComponent(workspaceId)}/v1/object/create`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Retrieve a list of objects based on an AQL. Note that the preferred endpoint is /aql
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-object/#api-object-navlist-aql-post
     * @param options Request options.
     */
    async getObjectsWithAql(options) {
        const { body, headers, errorStrategy, workspaceId } = options;
        const request = new Request("POST", `/jsm/assets/workspace/${encodeURIComponent(workspaceId)}/v1/object/navlist/aql`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Fetch Objects by AQL
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-object/#api-object-aql-post
     * @param options Request options.
     */
    async getObjectsByAql(options) {
        const { body, headers, errorStrategy, workspaceId, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/jsm/assets/workspace/${encodeURIComponent(workspaceId)}/v1/object/aql`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ObjectAttributeGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * List all attributes for the given object
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-object/#api-object-id-attributes-get
     * @param options Request options.
     */
    async getAttributes(options) {
        const { headers, errorStrategy, id, workspaceId } = options;
        const request = new Request("GET", `/jsm/assets/workspace/${encodeURIComponent(workspaceId)}/v1/object/${encodeURIComponent(id)}/attributes`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ObjectHistoryGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Retrieve the history entries for this object
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-object/#api-object-id-history-get
     * @param options Request options.
     */
    async getHistory(options) {
        const { headers, errorStrategy, id, workspaceId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/jsm/assets/workspace/${encodeURIComponent(workspaceId)}/v1/object/${encodeURIComponent(id)}/history`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ObjectReferenceGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Find all references for an object
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-object/#api-object-id-referenceinfo-get
     * @param options Request options.
     */
    async getReferences(options) {
        const { headers, errorStrategy, id, workspaceId } = options;
        const request = new Request("GET", `/jsm/assets/workspace/${encodeURIComponent(workspaceId)}/v1/object/${encodeURIComponent(id)}/referenceinfo`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ObjectTicketGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Relation between Jira issues and Assets objects
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objectconnectedtickets/#api-objectconnectedtickets-objectid-tickets-get
     * @param options Request options.
     */
    async getConnectedTickets(options) {
        const { headers, errorStrategy, objectId, workspaceId } = options;
        const request = new Request("GET", `/jsm/assets/workspace/${encodeURIComponent(workspaceId)}/v1/objectconnectedtickets/${encodeURIComponent(objectId)}/tickets`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ObjectSchemaGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Resource to find object schemas in Assets
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objectschema/#api-objectschema-list-get
     * @param options Request options.
     */
    async getSchemas(options) {
        const { headers, errorStrategy, workspaceId } = options;
        const request = new Request("GET", `/jsm/assets/workspace/${encodeURIComponent(workspaceId)}/v1/objectschema/list`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Create a new object schema
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objectschema/#api-objectschema-create-post
     * @param options Request options.
     */
    async createSchema(options) {
        const { body, headers, errorStrategy, workspaceId } = options;
        const request = new Request("POST", `/jsm/assets/workspace/${encodeURIComponent(workspaceId)}/v1/objectschema/create`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Find a schema by id
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objectschema/#api-objectschema-id-get
     * @param options Request options.
     */
    async getSchema(options) {
        const { headers, errorStrategy, id, workspaceId } = options;
        const request = new Request("GET", `/jsm/assets/workspace/${encodeURIComponent(workspaceId)}/v1/objectschema/${encodeURIComponent(id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Update an object schema
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objectschema/#api-objectschema-id-put
     * @param options Request options.
     */
    async updateSchema(options) {
        const { body, headers, errorStrategy, id, workspaceId } = options;
        const request = new Request("PUT", `/jsm/assets/workspace/${encodeURIComponent(workspaceId)}/v1/objectschema/${encodeURIComponent(id)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Delete a schema
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objectschema/#api-objectschema-id-delete
     * @param options Request options.
     */
    async deleteSchema(options) {
        const { headers, errorStrategy, id, workspaceId } = options;
        const request = new Request("DELETE", `/jsm/assets/workspace/${encodeURIComponent(workspaceId)}/v1/objectschema/${encodeURIComponent(id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Find all object type attributes for this object schema
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objectschema/#api-objectschema-id-attributes-get
     * @param options Request options.
     */
    async getSchemaObjectTypeAttributes(options) {
        const { headers, errorStrategy, id, workspaceId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/jsm/assets/workspace/${encodeURIComponent(workspaceId)}/v1/objectschema/${encodeURIComponent(id)}/attributes`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Find all object types for this object schema
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objectschema/#api-objectschema-id-objecttypes-flat-get
     * @param options Request options.
     */
    async getSchemaObjectTypes(options) {
        const { headers, errorStrategy, id, workspaceId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/jsm/assets/workspace/${encodeURIComponent(workspaceId)}/v1/objectschema/${encodeURIComponent(id)}/objecttypes/flat`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ObjectTypeGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Attribute = new ObjectTypeAttributeGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
     * Find an object type by id
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objecttype/#api-objecttype-id-get
     * @param options Request options.
     */
    async getType(options) {
        const { headers, errorStrategy, id, workspaceId } = options;
        const request = new Request("GET", `/jsm/assets/workspace/${encodeURIComponent(workspaceId)}/v1/objecttype/${encodeURIComponent(id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Update an existing object type
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objecttype/#api-objecttype-id-put
     * @param options Request options.
     */
    async updateType(options) {
        const { body, headers, errorStrategy, id, workspaceId } = options;
        const request = new Request("PUT", `/jsm/assets/workspace/${encodeURIComponent(workspaceId)}/v1/objecttype/${encodeURIComponent(id)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Delete an object type
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objecttype/#api-objecttype-id-delete
     * @param options Request options.
     */
    async deleteType(options) {
        const { headers, errorStrategy, id, workspaceId } = options;
        const request = new Request("DELETE", `/jsm/assets/workspace/${encodeURIComponent(workspaceId)}/v1/objecttype/${encodeURIComponent(id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Find all attributes for this object type
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objecttype/#api-objecttype-id-attributes-get
     * @param options Request options.
     */
    async getTypeAttributes(options) {
        const { headers, errorStrategy, id, workspaceId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/jsm/assets/workspace/${encodeURIComponent(workspaceId)}/v1/objecttype/${encodeURIComponent(id)}/attributes`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Change position of this object type
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objecttype/#api-objecttype-id-position-post
     * @param options Request options.
     */
    async changeTypePosition(options) {
        const { body, headers, errorStrategy, id, workspaceId } = options;
        const request = new Request("POST", `/jsm/assets/workspace/${encodeURIComponent(workspaceId)}/v1/objecttype/${encodeURIComponent(id)}/position`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Create a new object type
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objecttype/#api-objecttype-create-post
     * @param options Request options.
     */
    async createType(options) {
        const { body, headers, errorStrategy, workspaceId } = options;
        const request = new Request("POST", `/jsm/assets/workspace/${encodeURIComponent(workspaceId)}/v1/objecttype/create`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ObjectTypeAttributeGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Create a new attribute on the given object type
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objecttypeattribute/#api-objecttypeattribute-objecttypeid-post
     * @param options Request options.
     */
    async createAttribute(options) {
        const { body, headers, errorStrategy, objectTypeId, workspaceId } = options;
        const request = new Request("POST", `/jsm/assets/workspace/${encodeURIComponent(workspaceId)}/v1/objecttypeattribute/${encodeURIComponent(objectTypeId)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Update an existing object type attribute
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objecttypeattribute/#api-objecttypeattribute-objecttypeid-id-put
     * @param options Request options.
     */
    async updateAttribute(options) {
        const { body, headers, errorStrategy, id, objectTypeId, workspaceId } = options;
        const request = new Request("PUT", `/jsm/assets/workspace/${encodeURIComponent(workspaceId)}/v1/objecttypeattribute/${encodeURIComponent(objectTypeId)}/${encodeURIComponent(id)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Delete an existing object type attribute
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-objecttypeattribute/#api-objecttypeattribute-id-delete
     * @param options Request options.
     */
    async deleteAttribute(options) {
        const { headers, errorStrategy, id, workspaceId } = options;
        const request = new Request("DELETE", `/jsm/assets/workspace/${encodeURIComponent(workspaceId)}/v1/objecttypeattribute/${encodeURIComponent(id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ProgressGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Show ongoing import process
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-progress/#api-progress-category-imports-id-get
     * @param options Request options.
     */
    async getImportProgress(options) {
        const { headers, errorStrategy, id, workspaceId } = options;
        const request = new Request("GET", `/jsm/assets/workspace/${encodeURIComponent(workspaceId)}/v1/progress/category/imports/${encodeURIComponent(id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ConfigGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Find all status
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-config/#api-config-statustype-get
     * @param options Request options.
     */
    async getConfigStatuses(options) {
        const { headers, errorStrategy, workspaceId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/jsm/assets/workspace/${encodeURIComponent(workspaceId)}/v1/config/statustype`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Create a new status
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-config/#api-config-statustype-post
     * @param options Request options.
     */
    async createConfigStatus(options) {
        const { body, headers, errorStrategy, workspaceId } = options;
        const request = new Request("POST", `/jsm/assets/workspace/${encodeURIComponent(workspaceId)}/v1/config/statustype`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Find a status by id
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-config/#api-config-statustype-id-get
     * @param options Request options.
     */
    async getConfigStatus(options) {
        const { headers, errorStrategy, id, workspaceId } = options;
        const request = new Request("GET", `/jsm/assets/workspace/${encodeURIComponent(workspaceId)}/v1/config/statustype/${encodeURIComponent(id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Update an existing status
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-config/#api-config-statustype-id-put
     * @param options Request options.
     */
    async updateConfigStatus(options) {
        const { body, headers, errorStrategy, id, workspaceId } = options;
        const request = new Request("PUT", `/jsm/assets/workspace/${encodeURIComponent(workspaceId)}/v1/config/statustype/${encodeURIComponent(id)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Delete an existing status
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-config/#api-config-statustype-id-delete
     * @param options Request options.
     */
    async deleteConfigStatus(options) {
        const { headers, errorStrategy, id, workspaceId } = options;
        const request = new Request("DELETE", `/jsm/assets/workspace/${encodeURIComponent(workspaceId)}/v1/config/statustype/${encodeURIComponent(id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class GlobalGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Update general configuration for object schema
     * Documentation: https://developer.atlassian.com/cloud/assets/rest/api-group-global/#api-global-config-objectschema-id-property-post
     * @param options Request options.
     */
    async updateGlobalObjectSchema(options) {
        const { body, headers, errorStrategy, workspaceId, id } = options;
        const request = new Request("POST", `/jsm/assets/workspace/${encodeURIComponent(workspaceId)}/v1/global/config/objectschema/${encodeURIComponent(id)}/property`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
//# sourceMappingURL=index.js.map