/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { ObjectListResultAsResponse } from "../definitions/ObjectListResultAsResponse";
import { ErrorStrategyOption } from "../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
export interface GetObjectsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The Jira Service Management REST API uses the workspaceId to identify your individual instance of Assets. You must include the workspaceId when making any calls to the REST API.
     */
    workspaceId: string;
    /**
     * The query to determine which objects that should be fetched. E.g. objectType = "Computer". The empty AQL means all objects
     */
    qlQuery?: string;
    /**
     * Which page to fetch when paginating through the response
     */
    page?: number;
    /**
     * The amount of objects returned per page
     */
    resultPerPage?: number;
    /**
     * Should the objects attributes be included in the response. If this parameter is false only the information on the object will be returned and the object attributes will not be present
     */
    includeAttributes?: boolean;
    /**
     * How many levels of attributes should be included. E.g. consider an object A that has a reference to object B that has a reference to object C. If object A is included in the response and includeAttributesDeep=1 object A's reference to object B will be included in the attributes of object A but object B's reference to object C will not be included. However if the includeAttributesDeep=2 then object B's reference to object C will be included in object B's attributes
     */
    includeAttributesDeep?: number;
    /**
     * Should the response include the object type attribute definition for each attribute that is returned with the objects
     */
    includeTypeAttributes?: boolean;
    /**
     * Include information about open Jira issues. Should each object have information if open tickets are connected to the object?
     */
    includeExtendedInfo?: boolean;
}
declare type GetObjectsResponseOKType = ObjectListResultAsResponse;
export interface GetObjectsResponseOK extends GetObjectsResponseOKType {
}
export declare type GetObjectsResponseError = undefined;
export {};
//# sourceMappingURL=aql.d.ts.map