/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { ObjectAsResponse } from "../definitions/ObjectAsResponse";
import { ErrorStrategyOption } from "../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { ObjectIn } from "../definitions/ObjectIn";
import { ObjectFilterParams } from "../definitions/ObjectFilterParams";
import { ObjectListResultAsResponse } from "../definitions/ObjectListResultAsResponse";
import { ObjectAQLParams } from "../definitions/ObjectAQLParams";
import { ObjectListInclTypeAttributesEntryResultAsResponse } from "../definitions/ObjectListInclTypeAttributesEntryResultAsResponse";
export interface GetObjectRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The object id to operate on
     */
    id: string;
    /**
     * The Jira Service Management REST API uses the workspaceId to identify your individual instance of Assets. You must include the workspaceId when making any calls to the REST API.
     */
    workspaceId: string;
}
declare type GetObjectResponseOKType = ObjectAsResponse;
export interface GetObjectResponseOK extends GetObjectResponseOKType {
}
export declare type GetObjectResponseError = undefined;
export interface UpdateObjectRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The object id to operate on
     */
    id: string;
    /**
     * The Jira Service Management REST API uses the workspaceId to identify your individual instance of Assets. You must include the workspaceId when making any calls to the REST API.
     */
    workspaceId: string;
    body: ObjectIn;
}
declare type UpdateObjectResponseOKType = ObjectAsResponse;
export interface UpdateObjectResponseOK extends UpdateObjectResponseOKType {
}
export declare type UpdateObjectResponseError = undefined;
export interface DeleteObjectRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The object id to operate on
     */
    id: string;
    /**
     * The Jira Service Management REST API uses the workspaceId to identify your individual instance of Assets. You must include the workspaceId when making any calls to the REST API.
     */
    workspaceId: string;
}
export declare type DeleteObjectResponseOK = undefined;
export declare type DeleteObjectResponseError = undefined;
export interface CreateObjectRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The Jira Service Management REST API uses the workspaceId to identify your individual instance of Assets. You must include the workspaceId when making any calls to the REST API.
     */
    workspaceId: string;
    body: ObjectIn;
}
declare type CreateObjectResponseOKType = ObjectAsResponse;
export interface CreateObjectResponseOK extends CreateObjectResponseOKType {
}
export declare type CreateObjectResponseError = undefined;
export interface GetObjectsWithAqlRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The Jira Service Management REST API uses the workspaceId to identify your individual instance of Assets. You must include the workspaceId when making any calls to the REST API.
     */
    workspaceId: string;
    body: ObjectFilterParams;
}
declare type GetObjectsWithAqlResponseOKType = ObjectListResultAsResponse;
export interface GetObjectsWithAqlResponseOK extends GetObjectsWithAqlResponseOKType {
}
export declare type GetObjectsWithAqlResponseError = undefined;
export interface GetObjectsByAqlRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The Jira Service Management REST API uses the workspaceId to identify your individual instance of Assets. You must include the workspaceId when making any calls to the REST API.
     */
    workspaceId: string;
    /**
     * The starting index for the next page of results
     */
    startAt?: number;
    /**
     * The maximum number of objects to return in this page of results. Actual number of results may be less, for example, if the last page of results is returned.
     */
    maxResults?: number;
    /**
     * Should the objects attributes be included in the response. If this parameter is false only the information on the object will be returned and the object attributes will not be present
     */
    includeAttributes?: boolean;
    body: ObjectAQLParams;
}
declare type GetObjectsByAqlResponseOKType = ObjectListInclTypeAttributesEntryResultAsResponse;
export interface GetObjectsByAqlResponseOK extends GetObjectsByAqlResponseOKType {
}
export declare type GetObjectsByAqlResponseError = undefined;
export {};
//# sourceMappingURL=object.d.ts.map